Introduction
============

Django-ostinato is a collection of applications that aims to bring together
some of the most common features expected from a CMS.

Please feel free to log any issues on the `Github issue tracker <https://github.com/andrewebdev/django-ostinato/issues>`_.

If you want to track actual progress, as well as a list of features/bugs we
are currently working on, you can do so on our `Pivotal Tracker <https://www.pivotaltracker.com/projects/417365>`_ page.


For more detailed information `read the documentation <http://django-ostinato.readthedocs.org/en/latest/index.html>`_.
